@@ -2,7 +2,7 @@
  *
  *
  * Copyright (C) 2005 Jim Chandler <jim@n0vh.org>
- * Portions Copyright (C) 2000-2019 The Xastir Group
+ * Portions Copyright (C) 2000-2023 The Xastir Group
  *
  * Portions copied from Bruce Bennett's excellent Davis WX work
  *
@@ -29,7 +29,7 @@
         Output is to the ip hostname:port required in the
         command line.
 
-    ACKNOWLEGEMENTS:
+    ACKNOWLEDGEMENTS:
 
         Elements of this software are taken from wx200d ver 1.2
         by Tim Witham <twitham@quiknet.com>, and it is modeled
@@ -1050,8 +1050,8 @@ int main(int argc, char **argv)
     exit(10);
   }
   /* <dirkx@covalent.net> / April 2001 Minor change to allow quick
-   * (re)start of deamon or client while there are pending
-   * conncections during the quit. To avoid addresss/port in use
+   * (re)start of daemon or client while there are pending
+   * conncections during the quit. To avoid address/port in use
    * error.  */
   i = 1;
   if (setsockopt(s, SOL_SOCKET, SO_REUSEADDR, &i, sizeof(i)) == -1)
