@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -79,7 +79,7 @@
 // with hundreds of counties across many states.  I have a prototye of a
 // polygon generator - but that is a whole other can of worms
 //
-// WARN - warning - Severe or dangerous weather is occuring or is about to
+// WARN - warning - Severe or dangerous weather is occurring or is about to
 // occur in a geographical area.  This we do a pretty good job on output.
 //
 // ADVIS - advisory - this can be trivial all the way to a tornado report.
@@ -293,9 +293,7 @@
 #include <assert.h>
 #include <ctype.h>
 
-#ifdef  HAVE_LOCALE_H
-  #include <locale.h>
-#endif  // HAVE_LOCALE_H
+#include <locale.h>
 
 #include <Xm/XmAll.h>
 
@@ -419,7 +417,7 @@ int wx_alert_keys_equal(void *key1, void *key2)
   // and what the results were of the match.  If different
   // unique_string's hash to the same value, we run through this
   // compare once for each already-inserted record that also has
-  // the same hash vaue.
+  // the same hash value.
   //    fprintf(stderr,"Comparing %s to %s\t",(char *)key1,(char *)key2);
 
   if (strlen((char *)t1->unique_string) == strlen((char *)t2->unique_string)
