@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,17 +27,19 @@
 #define MAX_COLORS 81
 
 #define MAX_COLORNAME 40
-typedef struct {
-    char colorname[MAX_COLORNAME];
-    XColor color;
+typedef struct
+{
+  char colorname[MAX_COLORNAME];
+  XColor color;
 } color_load;
 
-typedef enum {
-    NOT_TRUE_NOR_DIRECT,
-    RGB_565,
-    RGB_555,
-    RGB_888,
-    RGB_OTHER
+typedef enum
+{
+  NOT_TRUE_NOR_DIRECT,
+  RGB_565,
+  RGB_555,
+  RGB_888,
+  RGB_OTHER
 } Pixel_Format;
 extern Pixel_Format visual_type;
 extern int visual_depth;
