@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,22 +31,10 @@
 #include <ctype.h>
 #include <Xm/XmAll.h>
 
-// The following files support setting the system time from the GPS
-#if TIME_WITH_SYS_TIME
-  // Define needed by some versions of Linux in order to define
-  // strptime()
-  #ifndef __USE_XOPEN
-    #define __USE_XOPEN
-  #endif
+#if HAVE_SYS_TIME_H
   #include <sys/time.h>
-  #include <time.h>
-#else   // TIME_WITH_SYS_TIME
-  #if HAVE_SYS_TIME_H
-    #include <sys/time.h>
-  #else  // HAVE_SYS_TIME_H
-    #include <time.h>
-  #endif // HAVE_SYS_TIME_H
-#endif  // TIME_WITH_SYS_TIME
+#endif // HAVE_SYS_TIME_H
+#include <time.h>
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -986,16 +974,17 @@ void create_garmin_waypoint(long latitude,long longitude,char *call_sign)
   //fprintf(stderr,"%s\n",out_string2);
 }
 
-// Test if this is a GGA string, irrespective of what constellation it
-// might be for.  This should allow us to support GPS, GLONASS, Gallileo,
-// Beidou, or GNSS receivers, and multi-constellation receivers.
+// Test if this is a GGA string, irrespective of what talker produced
+// it.  This should allow us to support GPS, GLONASS, Gallileo,
+// Beidou, or GNSS receivers, and multi-constellation receivers ($GP,
+// $GN, etc.), but also other talkers like Integrated Instrumentation
+// ($II).
 int isGGA(char *gps_line_data)
 {
   int retval;
   retval = (strncmp(gps_line_data,"$",1)==0);
   retval = retval && ((strlen(gps_line_data)>7)
                       && strncmp(&(gps_line_data[3]),"GGA,",4)==0);
-  retval = retval && (strchr("PNALB",gps_line_data[2])!=0);
   return (retval);
 }
 
@@ -1006,6 +995,5 @@ int isRMC(char *gps_line_data)
   retval = (strncmp(gps_line_data,"$",1)==0);
   retval = retval && ((strlen(gps_line_data)>7)
                       && strncmp(&(gps_line_data[3]),"RMC,",4)==0);
-  retval = retval && (strchr("PNALB",gps_line_data[2])!=0);
   return (retval);
 }
