@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,11 +37,6 @@
 #include <pwd.h>
 #include <errno.h>
 
-// Needed for Solaris
-#ifdef HAVE_STRINGS_H
-  #include <strings.h>
-#endif  // HAVE_STRINGS_H
-
 #include <dirent.h>
 #include <netinet/in.h>
 #include <Xm/XmAll.h>
@@ -78,17 +73,10 @@
 #define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
 
 #ifdef HAVE_MAGICK
-  #if TIME_WITH_SYS_TIME
+  #if HAVE_SYS_TIME_H
     #include <sys/time.h>
-    #include <time.h>
-  #else   // TIME_WITH_SYS_TIME
-    #if HAVE_SYS_TIME_H
-      #include <sys/time.h>
-    #else  // HAVE_SYS_TIME_H
-      #include <time.h>
-    #endif // HAVE_SYS_TIME_H
-  #endif  // TIME_WITH_SYS_TIME
-  #undef RETSIGTYPE
+  #endif // HAVE_SYS_TIME_H
+  #include <time.h>
   // TVR: "stupid ImageMagick"
   // The problem is that magick/api.h includes Magick's config.h file, and that
   // pulls in all the same autoconf-generated defines that we use.
@@ -109,12 +97,15 @@
   #undef PACKAGE_TARNAME
   #define XASTIR_PACKAGE_VERSION PACKAGE_VERSION
   #undef PACKAGE_VERSION
-  #ifdef HAVE_GRAPHICSMAGICK
-    /*#include <GraphicsMagick/magick/api.h>*/
-    #include <magick/api.h>
-  #else   // HAVE_GRAPHICSMAGICK
-    #include <magick/api.h>
-  #endif  // HAVE_GRAPHICSMAGICK
+  #ifdef HAVE_MAGICK
+    #ifdef HAVE_MAGICKCORE_MAGICKCORE_H
+      #include <MagickCore/MagickCore.h>
+    #else
+      #ifdef HAVE_MAGICK_API_H
+        #include <magick/api.h>
+      #endif // HAVE_MAGICK_API_H
+    #endif //HAVE_MAGICKCORE_MAGICKCORE_H
+  #endif //HAVE_MAGICK
   #undef PACKAGE_BUGREPORT
   #define PACKAGE_BUGREPORT XASTIR_PACKAGE_BUGREPORT
   #undef XASTIR_PACKAGE_BUGREPORT
@@ -659,28 +650,19 @@ void draw_WMS_map (Widget w,
   // try to reduce the number of colors in an image.
   // This may take some time, so it would be best to do ahead of
   // time if it is a static image.
-#if (MagickLibVersion < 0x0540)
-  if (visual_type == NOT_TRUE_NOR_DIRECT && GetNumberColors(image, NULL) > 128)
-  {
-#else   // MagickLib >= 540
   if (visual_type == NOT_TRUE_NOR_DIRECT && GetNumberColors(image, NULL, &exception) > 128)
   {
-#endif  // MagickLib Version
 
     if (image->storage_class == PseudoClass)
     {
-#if (MagickLibVersion < 0x0549)
-      CompressColormap(image); // Remove duplicate colors
-#else // MagickLib >= 0x0549
       CompressImageColormap(image); // Remove duplicate colors
-#endif  // MagickLibVersion < 0x0549
     }
 
     // Quantize down to 128 will go here...
   }
 
 
-#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x0669)
+#if defined(HAVE_GRAPHICSMAGICK)
   pixel_pack = GetImagePixels(image, 0, 0, image->columns, image->rows);
 #else
   pixel_pack = GetAuthenticPixels(image, 0, 0, image->columns, image->rows, &exception);
@@ -708,11 +690,7 @@ void draw_WMS_map (Widget w,
     index_pack = AccessMutableIndexes(image);
   #endif
 #else
-  #if (MagickLibVersion < 0x0669)
-    index_pack = GetIndexes(image);
-  #else
     index_pack = GetAuthenticIndexQueue(image);
-  #endif
 #endif
   if (image->storage_class == PseudoClass && !index_pack)
   {
@@ -883,11 +861,7 @@ void draw_WMS_map (Widget w,
     fprintf(stderr,"XX: %ld YY:%ld Sx %f %d Sy %f %d\n",
             map_c_L, map_c_T, map_c_dx,(int) (map_c_dx / scale_x), map_c_dy, (int) (map_c_dy / scale_y));
     fprintf(stderr,"Image size %d %d\n", width, height);
-#if (MagickLibVersion < 0x0540)
-    fprintf(stderr,"Unique colors = %d\n", GetNumberColors(image, NULL));
-#else // MagickLib < 540
     fprintf(stderr,"Unique colors = %ld\n", GetNumberColors(image, NULL, &exception));
-#endif // MagickLib < 540
     fprintf(stderr,"XX: %ld YY:%ld Sx %f %d Sy %f %d\n", map_c_L, map_c_T,
             map_c_dx,(int) (map_c_dx / scale_x), map_c_dy, (int) (map_c_dy / scale_y));
     fprintf(stderr,"image matte is %i\n", image->matte);
