@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,11 +38,6 @@
 #include <pwd.h>
 #include <errno.h>
 
-// Needed for Solaris
-#ifdef HAVE_STRINGS_H
-  #include <strings.h>
-#endif  // HAVE_STRINGS_H
-
 #include <dirent.h>
 #include <netinet/in.h>
 #include <Xm/XmAll.h>
@@ -93,17 +88,10 @@
 
 
 #ifdef HAVE_MAGICK
-  #if TIME_WITH_SYS_TIME
+  #if HAVE_SYS_TIME_H
     #include <sys/time.h>
-    #include <time.h>
-  #else   // TIME_WITH_SYS_TIME
-    #if HAVE_SYS_TIME_H
-      #include <sys/time.h>
-    #else  // HAVE_SYS_TIME_H
-      #include <time.h>
-    #endif // HAVE_SYS_TIME_H
-  #endif  // TIME_WITH_SYS_TIME
-  #undef RETSIGTYPE
+  #endif // HAVE_SYS_TIME_H
+  #include <time.h>
   // TVR: "stupid ImageMagick"
   // The problem is that magick/api.h includes Magick's config.h file, and that
   // pulls in all the same autoconf-generated defines that we use.
@@ -124,7 +112,15 @@
   #undef PACKAGE_TARNAME
   #define XASTIR_PACKAGE_VERSION PACKAGE_VERSION
   #undef PACKAGE_VERSION
-  #include <magick/api.h>
+  #ifdef HAVE_MAGICK
+    #ifdef HAVE_MAGICKCORE_MAGICKCORE_H
+      #include <MagickCore/MagickCore.h>
+    #else
+      #ifdef HAVE_MAGICK_API_H
+        #include <magick/api.h>
+      #endif // HAVE_MAGICK_API_H
+    #endif //HAVE_MAGICKCORE_MAGICKCORE_H
+  #endif //HAVE_MAGICK
   #undef PACKAGE_BUGREPORT
   #define PACKAGE_BUGREPORT XASTIR_PACKAGE_BUGREPORT
   #undef XASTIR_PACKAGE_BUGREPORT
@@ -1168,7 +1164,6 @@ void draw_geo_image_map (Widget w,
       {
         imagemagick_options.normalize = 1;
       }
-#if (MagickLibVersion >= 0x0539)
       if (strncasecmp(line, "LEVEL", 5) == 0)
       {
         xastir_snprintf(imagemagick_options.level,
@@ -1176,7 +1171,6 @@ void draw_geo_image_map (Widget w,
                         "%s",
                         line+6);
       }
-#endif  // MagickLibVersion >= 0x0539
       if (strncasecmp(line, "MODULATE", 8) == 0)
       {
         xastir_snprintf(imagemagick_options.modulate,
@@ -2241,7 +2235,6 @@ void draw_geo_image_map (Widget w,
     return;
   }
 
-#if (MagickLibVersion >= 0x0539)
   if (imagemagick_options.level[0] != '\0')
   {
     if (debug_level & 16)
@@ -2250,7 +2243,6 @@ void draw_geo_image_map (Widget w,
     }
     LevelImage(image, imagemagick_options.level);
   }
-#endif  // MagickLibVersion >= 0x0539
 
   if (check_interrupt(image, image_info,
                       &exception, &da, &pixmap, &gc, screen_width, screen_height))
@@ -2304,7 +2296,11 @@ void draw_geo_image_map (Widget w,
     //        target=GetOnePixel(image,0,0);
     for (y=0; y < (long) image->rows; y++)
     {
+#if defined(HAVE_GRAPHICSMAGICK)
       q=GetImagePixels(image,0,y,image->columns,1);
+#else
+      q=GetAuthenticPixels(image,0,y,image->columns,1,&exception);
+#endif
       if (q == (PixelPacket *) NULL)
       {
         fprintf(stderr, "GetImagePixels Failed....\n");
@@ -2318,10 +2314,17 @@ void draw_geo_image_map (Widget w,
         }
         q++;
       }
+#if defined(HAVE_GRAPHICSMAGICK)
       if (!SyncImagePixels(image))
       {
         fprintf(stderr, "SyncImagePixels Failed....\n");
       }
+#else
+      if (!SyncAuthenticPixels(image,&exception))
+      {
+        fprintf(stderr, "SyncImagePixels Failed....\n");
+      }
+#endif
     }
   }
 
@@ -2329,21 +2332,12 @@ void draw_geo_image_map (Widget w,
   // try to reduce the number of colors in an image.
   // This may take some time, so it would be best to do ahead of
   // time if it is a static image.
-#if (MagickLibVersion < 0x0540)
-  if (visual_type == NOT_TRUE_NOR_DIRECT && GetNumberColors(image, NULL) > 128)
-  {
-#else   // MagickLib >= 540
   if (visual_type == NOT_TRUE_NOR_DIRECT && GetNumberColors(image, NULL, &exception) > 128)
   {
-#endif  // MagickLib Version
 
     if (image->storage_class == PseudoClass)
     {
-#if (MagickLibVersion < 0x0549)
-      CompressColormap(image); // Remove duplicate colors
-#else // MagickLib >= 0x0549
       CompressImageColormap(image); // Remove duplicate colors
-#endif  // MagickLibVersion < 0x0549
     }
 
     // Quantize down to 128 will go here...
@@ -2355,7 +2349,11 @@ void draw_geo_image_map (Widget w,
     return;
   }
 
+#if defined(HAVE_GRAPHICSMAGICK)
   pixel_pack = GetImagePixels(image, 0, 0, image->columns, image->rows);
+#else
+  pixel_pack = GetAuthenticPixels(image, 0, 0, image->columns, image->rows,&exception);
+#endif
   if (!pixel_pack)
   {
     fprintf(stderr,"pixel_pack == NULL!!!");
@@ -2384,11 +2382,7 @@ void draw_geo_image_map (Widget w,
     index_pack = AccessMutableIndexes(image);
   #endif
 #else
-  #if (MagickLibVersion < 0x0669)
-    index_pack = GetIndexes(image);
-  #else
     index_pack = GetAuthenticIndexQueue(image);
-  #endif
 #endif
   if (image->storage_class == PseudoClass && !index_pack)
   {
@@ -2530,25 +2524,14 @@ void draw_geo_image_map (Widget w,
   if (debug_level & 16)
   {
     fprintf(stderr,"Image size %d %d\n", width, height);
-#if (MagickLibVersion < 0x0540)
-    fprintf(stderr,"Unique colors = %d\n", GetNumberColors(image, NULL));
-#else   // MagickLibVersion < 0x0540
     fprintf(stderr,"Unique colors = %ld\n", GetNumberColors(image, NULL, &exception));
-#endif  // MagickLibVersion < 0x0540
     fprintf(stderr,"XX: %ld YY:%ld Sx %f %d Sy %f %d\n", map_c_L, map_c_T,
             map_c_dx,(int) (map_c_dx / scale_x), map_c_dy, (int) (map_c_dy / scale_y));
 
-#if (MagickLibVersion < 0x0540)
-    fprintf(stderr,"is Gray Image = %i\n", IsGrayImage(image));
-    fprintf(stderr,"is Monochrome Image = %i\n", IsMonochromeImage(image));
-    //fprintf(stderr,"is Opaque Image = %i\n", IsOpaqueImage(image));
-    //fprintf(stderr,"is PseudoClass = %i\n", image->storage_class == PseudoClass);
-#else    // MagickLibVersion < 0x0540
     fprintf(stderr,"is Gray Image = %i\n", IsGrayImage( image, &exception ));
     fprintf(stderr,"is Monochrome Image = %i\n", IsMonochromeImage( image, &exception ));
     //fprintf(stderr,"is Opaque Image = %i\n", IsOpaqueImage( image, &exception ));
     //fprintf(stderr,"is PseudoClass = %i\n", image->storage_class == PseudoClass);
-#endif   // MagickLibVersion < 0x0540
 
     fprintf(stderr,"image matte is %i\n", image->matte);
     fprintf(stderr,"Colorspace = %i\n", image->colorspace);
