@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,12 +21,12 @@
  * Look at the README for more information on the program.
  */
 /****************************************************************************
- * MODULE:       R-Tree library 
- *              
+ * MODULE:       R-Tree library
+ *
  * AUTHOR(S):    Antonin Guttman - original code
  *               Melinda Green (melinda@superliminal.com) - major clean-up
  *                               and implementation of bounding spheres
- *               
+ *
  * PURPOSE:      Multidimensional index
  *
  */
@@ -39,13 +39,27 @@ int Xastir_LEAFCARD = MAXCARD;
 
 static int set_max(int *which, int new_max)
 {
-	if(2 > new_max || new_max > MAXCARD)
-		return 0;
-	*which = new_max;
-	return 1;
+  if(2 > new_max || new_max > MAXCARD)
+  {
+    return 0;
+  }
+  *which = new_max;
+  return 1;
 }
 
-int Xastir_RTreeSetNodeMax(int new_max) { return set_max(&Xastir_NODECARD, new_max); }
-int Xastir_RTreeSetLeafMax(int new_max) { return set_max(&Xastir_LEAFCARD, new_max); }
-int Xastir_RTreeGetNodeMax(void) { return Xastir_NODECARD; }
-int Xastir_RTreeGetLeafMax(void) { return Xastir_LEAFCARD; }
+int Xastir_RTreeSetNodeMax(int new_max)
+{
+  return set_max(&Xastir_NODECARD, new_max);
+}
+int Xastir_RTreeSetLeafMax(int new_max)
+{
+  return set_max(&Xastir_LEAFCARD, new_max);
+}
+int Xastir_RTreeGetNodeMax(void)
+{
+  return Xastir_NODECARD;
+}
+int Xastir_RTreeGetLeafMax(void)
+{
+  return Xastir_LEAFCARD;
+}
