@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,13 +35,9 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#ifdef  HAVE_LOCALE_H
-  #include <locale.h>
-#endif  // HAVE_LOCALE_H
+#include <locale.h>
 
-#ifdef HAVE_MATH_H
-  #include <math.h>
-#endif  // HAVE_MATH_H
+#include <math.h>
 
 #include "xastir.h"
 #include "wx.h"
